[![Build Status](https://github.com/dbbs-lab/bsb/actions/workflows/main.yml/badge.svg)](https://github.com/dbbs-lab/bsb/actions/workflows/main.yml)
[![Documentation](https://readthedocs.org/projects/bsb-arbor/badge/?version=latest)](https://bsb-arbor.readthedocs.io/en/latest/?badge=latest)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)

# bsb-arbor

bsb-arbor is a plugin of the [BSB](https://github.com/dbbs-lab/bsb)
It contains the interfaces and tools to simulate BSB circuits with the 
[Arbor simulator](https://arbor-sim.org/).

Comprehensive documentation is available at:

* [BSB Documentation](https://bsb.readthedocs.io/en/latest)
* [bsb-arbor Documentation](https://bsb-arbor.readthedocs.io/en/latest)
